@@ -5,7 +5,7 @@ from soil.fabric import eval_kwargs
 from soil.filesystem import temporary_directory
 from beanstalk import IDENTIFIER
 from beanstalk.decorators import beanstalk_role
-from beanstalk.tasks.utils import load_role_settings as load_beanstalk_settings
+from beanstalk.tasks.utils import load_role_settings as load_beanstalk_settings, set_verbose_level
 from beanstalk.titles import tool_title, section_title
 
 
@@ -21,6 +21,7 @@ def setup(settings_path=None, **settings_patches):
     settings_patches = eval_kwargs(settings_patches)
     beanstalk_settings = load_beanstalk_settings(local_settings_path=settings_path, **settings_patches)
     beanstalk_stack_base = beanstalk_settings['BEANSTALK_STACK_BASE']
+    set_verbose_level()
 
     # Install packages for building uwsgi
     print section_title('Install system packages')
@@ -45,6 +46,7 @@ def setup(settings_path=None, **settings_patches):
                 # Create build configuration
                 local('mkdir -p /usr/local/lib/uwsgi')
                 local('echo "[uwsgi]" >> buildconf/beanstalk.ini')
+                local('echo "main_plugin = python" >> buildconf/beanstalk.ini')
                 local('echo "inherit = base" >> buildconf/beanstalk.ini')
                 local('echo "plugin_dir = /usr/local/lib/uwsgi" >> buildconf/beanstalk.ini')
                 # Build and install
